@@ -292,7 +292,7 @@ public final class InternalUtility {
         }
         try {
             return Integer.parseInt(cl.substring(cl.charAt(0) == '$' ? COLOR_LABEL_PREFIX.length() : COLOR_LABEL_PREFIX_OLD.length()));
-        } catch (final NumberFormatException e) {
+        } catch (NumberFormatException e) {
             throw MessagingExceptionCodes.UNKNOWN_COLOR_LABEL.create(cl);
         }
     }
@@ -319,7 +319,7 @@ public final class InternalUtility {
     public static int parseColorLabel(final String cl, final int defaultValue) {
         try {
             return Integer.parseInt(cl.substring('$' == cl.charAt(0) ? COLOR_LABEL_PREFIX.length() : COLOR_LABEL_PREFIX_OLD.length()));
-        } catch (final NumberFormatException e) {
+        } catch (NumberFormatException e) {
             final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(Utility.class);
             log.debug("Inbvalid color label: {}", cl, e);
             return defaultValue;
