@@ -81,7 +81,7 @@ public final class TwitterEventHandler implements EventHandler {
                     }
                 }
             }
-        } catch (final Exception e) {
+        } catch (Exception e) {
             LOG.error("Error while handling SessionD event \"{}\"", topic, e);
         }
     }
