@@ -62,6 +62,7 @@ import java.util.Date;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
+import java.util.Optional;
 import javax.net.ssl.SSLHandshakeException;
 import org.apache.commons.io.FileUtils;
 import org.json.JSONArray;
@@ -82,8 +83,9 @@ import com.openexchange.rss.RssResult;
 import com.openexchange.rss.osgi.Services;
 import com.openexchange.rss.preprocessors.RssPreprocessor;
 import com.openexchange.rss.preprocessors.SanitizingPreprocessor;
-import com.openexchange.rss.util.RssProperties;
 import com.openexchange.rss.util.TimeoutHttpURLFeedFetcher;
+import com.openexchange.rss.utils.RssProperties;
+import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
 import com.sun.syndication.feed.synd.SyndContent;
@@ -139,8 +141,8 @@ public class RssAction implements AJAXActionService {
     @Override
     public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) throws OXException {
         List<OXException> warnings = new LinkedList<>();
-        List<SyndFeed> feeds = null;
 
+        List<SyndFeed> feeds;
         try {
             feeds = getAcceptedFeeds(getUrls(request), warnings);
         } catch (IllegalArgumentException | MalformedURLException e) {
@@ -150,7 +152,7 @@ public class RssAction implements AJAXActionService {
         }
 
         if (feeds == null) {
-            return new AJAXRequestResult(new ArrayList<RssResult>(), "rss").addWarnings(warnings);
+            return new AJAXRequestResult(new ArrayList<RssResult>(1), "rss").addWarnings(warnings);
         }
 
         List<RssResult> results = new ArrayList<>(feeds.size());
@@ -293,7 +295,9 @@ public class RssAction implements AJAXActionService {
     }
 
     /**
-     * Checks given URLs for validity (esp. host name blacklisting and port whitelisting) and adds not accepted feeds to the provided warnings list. Returns a list of accepted feeds for further processing
+     * Checks given URLs for validity (esp. host name black-listing and port white-listing) and adds not accepted feeds to the provided warnings list.
+     * <p>
+     * Returns a list of accepted feeds for further processing.
      *
      * @param urls - List of {@link URL}s to check
      * @param warnings - List of {@link OXException} that might be enhanced by possible errors
@@ -301,90 +305,112 @@ public class RssAction implements AJAXActionService {
      * @throws OXException
      */
     protected List<SyndFeed> getAcceptedFeeds(List<URL> urls, List<OXException> warnings) throws OXException {
-        List<SyndFeed> feeds = new LinkedList<>();
+        RssProperties rssProperties = Services.getService(RssProperties.class);
+        if (rssProperties == null) {
+            throw ServiceExceptionCode.absentService(RssProperties.class);
+        }
 
-        for (URL url : urls) {
-            if (RssProperties.isDenied(url.toString())) {
-                final OXException oxe = RssExceptionCodes.RSS_CONNECTION_ERROR.create(url.toString());
-                warnings.add(oxe);
-                continue;
+        int numberOfUrls = urls.size();
+        List<SyndFeed> feeds = new ArrayList<>(numberOfUrls);
+
+        if (numberOfUrls == 1) {
+            // Only one feed URL
+            URL url = urls.get(0);
+            if (rssProperties.isDenied(url.toString())) {
+                throw RssExceptionCodes.RSS_CONNECTION_ERROR.create(url.toString());
             }
-            try {
-                feeds.add(fetcher.retrieveFeed(url));
-            } catch (java.net.SocketTimeoutException e) {
-                OXException oxe = RssExceptionCodes.TIMEOUT_ERROR.create(e, url.toString());
-                if (1 == urls.size()) {
-                    throw oxe;
-                }
-                warnings.add(oxe);
-            } catch (UnsupportedEncodingException e) {
-                /* yeah, right... not happening for UTF-8 */
-                LOG.trace("", e);
-            } catch (IOException e) {
-                OXException oxe;
-                if (ExceptionUtils.isEitherOf(e, SSLHandshakeException.class)) {
-                    oxe = RssExceptionCodes.SSL_HANDSHAKE_ERROR.create(e, url.toString());
-                } else {
-                    oxe = RssExceptionCodes.IO_ERROR.create(e, e.getMessage(), url.toString());
-                }
-                if (1 == urls.size()) {
-                    throw oxe;
-                }
-                warnings.add(oxe);
-            } catch (ParsingFeedException parsingException) {
-                Throwable t = parsingException.getCause();
-                if (t != null && t instanceof IOException) {
-                    String exceptionMessage = t.getMessage();
-                    if (Strings.isNotEmpty(exceptionMessage) && exceptionMessage.contains("exceeded")) {
-                        ConfigurationService configService = Services.getService(ConfigurationService.class);
-                        int maximumAllowedSize = configService.getIntProperty("com.openexchange.messaging.rss.feed.size", 4194304);
-                        OXException oxe = RssExceptionCodes.RSS_SIZE_EXCEEDED.create(FileUtils.byteCountToDisplaySize(maximumAllowedSize), I(maximumAllowedSize));
-                        if (1 == urls.size()) {
-                            throw oxe;
-                        }
-                        warnings.add(oxe);
-                    }
-                }
-                final OXException oxe = RssExceptionCodes.INVALID_RSS.create(parsingException, url.toString());
-                if (1 == urls.size()) {
-                    throw oxe;
-                }
-                oxe.setCategory(Category.CATEGORY_WARNING);
-                warnings.add(oxe);
-            } catch (FeedException e) {
-                LOG.warn(COULD_NOT_LOAD_RSS_FEED_FROM, url, e);
-            } catch (FetcherException e) {
-                int responseCode = e.getResponseCode();
-                if (responseCode <= 0) {
-                    // No response code available
-                    LOG.warn(COULD_NOT_LOAD_RSS_FEED_FROM, url, e);
-                }
-                if (NOT_FOUND == responseCode) {
-                    LOG.debug("Resource could not be found: {}", url, e);
-                } else if (FORBIDDEN == responseCode) {
-                    LOG.debug("Authentication required for resource: {}", url, e);
-                } else if (responseCode >= 500 && responseCode < 600) {
-                    OXException oxe = RssExceptionCodes.RSS_HTTP_ERROR.create(e, Integer.valueOf(responseCode), url);
-                    if (1 == urls.size()) {
-                        throw oxe;
-                    }
+            retrieveAndAddFeed(url, feeds, Optional.empty());
+        } else {
+            // More than one feed URL
+            for (URL url : urls) {
+                if (rssProperties.isDenied(url.toString())) {
+                    OXException oxe = RssExceptionCodes.RSS_CONNECTION_ERROR.create(url.toString());
                     oxe.setCategory(Category.CATEGORY_WARNING);
                     warnings.add(oxe);
                 } else {
-                    LOG.warn(COULD_NOT_LOAD_RSS_FEED_FROM, url, e);
+                    retrieveAndAddFeed(url, feeds, Optional.of(warnings));
                 }
-            } catch (IllegalArgumentException e) {
-                String exceptionMessage = e.getMessage();
-                if (!"Invalid document".equals(exceptionMessage)) {
-                    throw AjaxExceptionCodes.INVALID_PARAMETER.create(e, exceptionMessage);
-                }
-                // There is no parser for current document
-                LOG.warn(COULD_NOT_LOAD_RSS_FEED_FROM, url);
             }
         }
+
         return feeds;
     }
 
+    private void retrieveAndAddFeed(URL url, List<SyndFeed> feeds, Optional<List<OXException>> optionalWarnings) throws OXException {
+        try {
+            feeds.add(fetcher.retrieveFeed(url));
+        } catch (java.net.SocketTimeoutException e) {
+            OXException oxe = RssExceptionCodes.TIMEOUT_ERROR.create(e, url.toString());
+            if (!optionalWarnings.isPresent()) {
+                throw oxe;
+            }
+            optionalWarnings.get().add(oxe);
+        } catch (UnsupportedEncodingException e) {
+            /* yeah, right... not happening for UTF-8 */
+            LOG.trace("", e);
+        } catch (IOException e) {
+            OXException oxe;
+            if (ExceptionUtils.isEitherOf(e, SSLHandshakeException.class)) {
+                oxe = RssExceptionCodes.SSL_HANDSHAKE_ERROR.create(e, url.toString());
+            } else {
+                oxe = RssExceptionCodes.IO_ERROR.create(e, e.getMessage(), url.toString());
+            }
+            if (!optionalWarnings.isPresent()) {
+                throw oxe;
+            }
+            optionalWarnings.get().add(oxe);
+        } catch (ParsingFeedException parsingException) {
+            Throwable t = parsingException.getCause();
+            if (t != null && t instanceof IOException) {
+                String exceptionMessage = t.getMessage();
+                if (Strings.isNotEmpty(exceptionMessage) && exceptionMessage.contains("exceeded")) {
+                    ConfigurationService configService = Services.getService(ConfigurationService.class);
+                    int maximumAllowedSize = configService.getIntProperty("com.openexchange.messaging.rss.feed.size", 4194304);
+                    OXException oxe = RssExceptionCodes.RSS_SIZE_EXCEEDED.create(FileUtils.byteCountToDisplaySize(maximumAllowedSize), I(maximumAllowedSize));
+                    if (!optionalWarnings.isPresent()) {
+                        throw oxe;
+                    }
+                    optionalWarnings.get().add(oxe);
+                }
+            }
+            final OXException oxe = RssExceptionCodes.INVALID_RSS.create(parsingException, url.toString());
+            if (!optionalWarnings.isPresent()) {
+                throw oxe;
+            }
+            oxe.setCategory(Category.CATEGORY_WARNING);
+            optionalWarnings.get().add(oxe);
+        } catch (FeedException e) {
+            LOG.warn(COULD_NOT_LOAD_RSS_FEED_FROM, url, e);
+        } catch (FetcherException e) {
+            int responseCode = e.getResponseCode();
+            if (responseCode <= 0) {
+                // No response code available
+                LOG.warn(COULD_NOT_LOAD_RSS_FEED_FROM, url, e);
+            }
+            if (NOT_FOUND == responseCode) {
+                LOG.debug("Resource could not be found: {}", url, e);
+            } else if (FORBIDDEN == responseCode) {
+                LOG.debug("Authentication required for resource: {}", url, e);
+            } else if (responseCode >= 500 && responseCode < 600) {
+                OXException oxe = RssExceptionCodes.RSS_HTTP_ERROR.create(e, Integer.valueOf(responseCode), url);
+                if (!optionalWarnings.isPresent()) {
+                    throw oxe;
+                }
+                oxe.setCategory(Category.CATEGORY_WARNING);
+                optionalWarnings.get().add(oxe);
+            } else {
+                LOG.warn(COULD_NOT_LOAD_RSS_FEED_FROM, url, e);
+            }
+        } catch (IllegalArgumentException e) {
+            String exceptionMessage = e.getMessage();
+            if (!"Invalid document".equals(exceptionMessage)) {
+                throw AjaxExceptionCodes.INVALID_PARAMETER.create(e, exceptionMessage);
+            }
+            // There is no parser for current document
+            LOG.warn(COULD_NOT_LOAD_RSS_FEED_FROM, url);
+        }
+    }
+
     /**
      * Sanitizes the specified string via the {@link HtmlService}
      *
